@@ -1,9 +1,9 @@
 describe('attribution', function() {
-    var map, attribution;
+    var map, attribution, div;
 
     beforeEach(function() {
         callbackResult = null;
-        var div = document.createElement('div');
+        div = document.createElement('div');
         div.style.width = '400px';
         div.style.height = '400px';
 
@@ -18,4 +18,8 @@ describe('attribution', function() {
     it('can have its content set', function() {
         expect($('.wax-attribution', map.parent).text()).toEqual('42');
     });
+
+    afterEach(function() {
+        map.destroy();
+    });
 });
